#
# spec file for package Box2D
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2012 Adam Mizerski <adam@mizerski.pl>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major 2
%define libname libbox2d
Name:           Box2D
Version:        2.4.1
Release:        2.14
Summary:        A 2D Physics Engine for Games
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://box2d.org/
Source0:        https://github.com/erincatto/box2d/archive/v%{version}.tar.gz#/box2d-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  cmake >= 3
BuildRequires:  gcc-c++
BuildRequires:  glew-devel
BuildRequires:  libX11-devel
BuildRequires:  libXcursor-devel
BuildRequires:  libXi-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libXrandr-devel
BuildRequires:  libglfw-devel

%description
Box2D is an open source C++ engine for simulating rigid bodies in 2D.

%package -n %{libname}%{major}
Summary:        A 2D Physics Engine for Games
Group:          System/Libraries

%description -n %{libname}%{major}
Box2D is an open source C++ engine for simulating rigid bodies in 2D.

%package -n %{libname}-devel
Summary:        A 2D Physics Engine for Games
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{major} = %{version}

%description -n %{libname}-devel
Box2D is an open source C++ engine for simulating rigid bodies in 2D.

%prep
%setup -q -n box2d-%{version}

%build
%cmake \
       -DBOX2D_BUILD_UNIT_TESTS=OFF
%make_build

%install
%cmake_install

%post -n %{libname}%{major} -p /sbin/ldconfig
%postun -n %{libname}%{major} -p /sbin/ldconfig

%files -n %{libname}%{major}
%license LICENSE
%doc README.md
%{_libdir}/%{libname}.so.%{major}
%{_libdir}/%{libname}.so.%{version}

%files -n %{libname}-devel
%{_includedir}/box2d
%{_libdir}/%{libname}.so
%{_libdir}/cmake/box2d

%changelog
* Thu Aug  5 2021 Dmitriy Perlow <dap.darkness@gmail.com>
- Disabled tests because of boo#1189082
- Removed useless cmake options
* Thu Feb 11 2021 Markéta Machová <mmachova@suse.com>
- Fix the source URL
* Thu Dec  3 2020 andy great <andythe_great@pm.me>
- Update to version 2.4.1.
  * API Changes
  * Extended distance joint to have a minimum and maximum limit.
  * Removed rope joint. Use the distance joint instead.
  * B2_USER_SETTINGS and b2_user_settings.h can control user
    data, length units, and maximum polygon vertices.
  * Default user data is now uintptr_t instead of void*
  * b2FixtureDef::restitutionThreshold lets you set the
    restitution velocity threshold per fixture.
  * BREAKING Changes
  * BREAKING: distance joint 0 stiffness now means the spring is
    turned off rather than making the joint rigid.
  * BREAKING: distance joint minimum and maximum must be set
    correctly to get old behavior.
  * Infrastructure
  * Library installation function available in CMake.
  * Shared library (DLL) option available.
  * Bug fixes
- Updates since 2.3.1
  * Infrastructure
  * Documentation in Doxygen format
  * Unit test support
  * Continuous integration testing using Travis CI
  * Limited use of C++11 (nullptr and override)
  * Collision
  * Chain and edge shape must now be one-sided to eliminate ghost
    collisions
  * Broad-phase optimizations
  * Added b2ShapeCast for linear shape casting
  * Dynamics
  * Joint limits are now predictive and not stateful
  * Experimental 2D cloth (rope)
  * b2Body::SetActive -> b2Body::SetEnabled
  * Better support for running multiple worlds
  * Handle zero density better
  * The body behaves like a static body
  * The body is drawn with a red color
  * Added translation limit to wheel joint
  * World dump now writes to box2d_dump.inl
  * Static bodies are never awake
  * All joints with spring-dampers now use stiffness and damping
  * Added utility functions to convert frequency and damping
    ratio to stiffness and damping
- Remove Box2D-fix-version-2.3.1.patch, fixed.
- Change package name from Box2D to box2d.
* Fri Aug 12 2016 jengelh@inai.de
- Replace strange buildroot definition
* Fri Jul 22 2016 jengelh@inai.de
- RPM group correction
* Thu Jul 21 2016 dap.darkness@gmail.com
- Fixed Factory review (License.txt is not packaged).
- Minor spec clean-up (may fix SLE build).
- Cmake release with debug info build type.
* Sun Jul 17 2016 bruno@ioda-net.ch
- Fixed tar.gz by osc service localrun download_files
- Fixed version in baselibs.conf (for 32bits packages)
- Added baselibs.conf as source1
* Wed Dec 16 2015 rpm@fthiessen.de
- Update to new upstream version 2.3.1:
  * Polygon creation now computes the convex hull.
  * The convex hull code will merge vertices closer than
  dm_linearSlop.
  * Vertices no longer need to be ordered.
  * New GUI
  * Various other bugfixes
- removed upstream patched Box2D_v2.2.1-lib64.patch
- replaced Box2D_v2.2.1-version.patch with
  Box2D-fix-version-2.3.1.patch
* Tue Jun 12 2012 adam@mizerski.pl
- new package
